@@ -7,16 +7,18 @@ def argument_parser(subparsers):
     parser.set_defaults(func=test)
     parser.add_argument("module", help="Python module with tests. E.g. 'sbg_wrappers.my_wrapper'. "
                                        "Same as nosetests '--where'", type=str, default='.')
+    parser.add_argument("--keep-container", "-k", help="Don't remove container when run finishes", type=bool)
 
 
-def test(project, module):
+def test(project, module, keep_container=False):
     check_project_dir(project)
     check_image(project)
     r = make_runner(project)
     try:
-        r.run_tests(module)
+        r.run_tests(module, remove=not keep_container)
     finally:
-        r.chown()
+        c = r.chown()
+        c.remove()
 
 
 __test__ = False
