@@ -1,5 +1,11 @@
 import logging
 
+import re
+import requests
+import base64
+import os
+import json
+
 from subprocess import Popen
 from docker.auth.auth import load_config
 
@@ -7,21 +13,48 @@ from sbdk.auth import login
 from sbdk.error import SbdkError
 
 
+
+DOCKER_CONFIG_FILENAME = '.dockercfg'
+ALLOWED_CHARS_RE = re.compile('^[a-z0-9]$')
+
+
 def dockerize(username):
-    return ''.join([c.lower() if c.isalnum() else '_' for c in username.decode('utf-8').encode('idna')])
+    return ''.join([chr if re.match(ALLOWED_CHARS_RE, chr) else '_' for chr in username.lower()])
+
+# def dockerize(username):
+#    return ''.join([c.lower() if (c.isalnum() or c == '_') else '' for c in username])  .decode('utf-8').encode('idna')
 
 
 def repo_name(project, user):
-    ret = project.docker_registry_name + '/' + dockerize(user) + '/' + project.name
+    saved_user = project.state.get('username')
+    if not saved_user:
+        saved_user = dockerize(user)
+        project.state['username'] = saved_user
+        project.state.save()
+    ret = project.docker_registry_name + '/' + saved_user + '/' + project.name
     return ret
 
 
-def store_credentials(docker_registry_name, username, password, email=None):
+def store_credentials(docker_registry_name, username, password, cfg, email=None):
     email = email or '%s@example.com' % username
-    login = Popen(['docker', 'login', '-u', username, '-p', password, '-e', email, docker_registry_name])
-    login.wait()
-    #client = docker.Client()
-    #client.login(username, password, email, docker_registry_name)
+
+    def convert_to_dockercfg(cfg):
+        def encode_auth(username, password):
+            return base64.b64encode(username + b':' + password)
+
+        dockercfg = {}
+        for repo, auth in cfg.iteritems():
+            dockercfg[repo] = {'auth': encode_auth(auth['username'], auth['password']), 'email': auth['email']}
+        return dockercfg
+
+    config_file = os.path.join(os.environ.get('HOME', '.'), DOCKER_CONFIG_FILENAME)
+    if not cfg.get(docker_registry_name, None):
+        cfg[docker_registry_name] = {}
+    cfg[docker_registry_name]['username'], cfg[docker_registry_name]['password'], cfg[docker_registry_name]['email'] \
+        = username, password, email
+
+    with open(config_file, 'w') as outfile:
+        json.dump(convert_to_dockercfg(cfg), outfile)
 
 
 class Container(object):
@@ -108,10 +141,11 @@ class Container(object):
         self.docker.push(self.repository)
 
     def load_credentials(self, renew=False):
-        cfg = load_config().get(self.project.docker_registry_url, None)
+        cfg = load_config()
         if renew or not cfg:
             self._user, self._token = login(self.project)
-            store_credentials(self.project.docker_registry_url, self._user, self._token)
+            store_credentials(self.project.docker_registry_url, self._user, self._token, cfg)
+
         else:
             self._user = cfg['username']
             self._token = cfg['password']
