@@ -3,7 +3,7 @@ from sbgsdk.errors import *
 
 class JobException(Exception):
     def __json__(self):
-        return {'$$type': 'error', 'message': self.message}
+        return {'$$type': 'error', 'message': self.message or str(self)}
 
     @classmethod
     def from_dict(cls, d):
