@@ -35,7 +35,11 @@ class Wrapper(object):
         result = getattr(self, method)(**args)
         if result is None:
             self.outputs._save_meta()
-            return Outputs(self.outputs.__json__())
+            out_dict = self.outputs.__json__()
+            for item in self.outputs:
+                if item.id not in out_dict or not item.value:
+                    out_dict[item.id] = []
+            return Outputs(out_dict)
         return result
 
     def get_requirements(self):
